# TRecord
TRecord is an interactive command line SQL client.

It is initially designed for Enterprise Production Systems.

The systems that it works on and with are,
  - Redhat Linux + Python 3, as the client machine
  - Oracle
  - Teradata
  - Microsoft SQL Server
  - MySQL

### Installation

```sh
$ pip3 install trecord
```


### Usage

```sh
$ trecord --help
```
